# `channel_advisor`

import channel_advisor

get_access_token(headers, payload) <br>
get_product_id(token, sku) <br>
get_fba_product_id(token, asin) <br>
get_product_by_id(token, product_id) <br>
get_bundle_components(token, product_id) <br>
get_components(token, product_id) <br>
add_or_update_attribute(token, product_id, attribute_name, attribute_value) <br>
get_product_with_attributes_by_id(token, product_id) <br>
get_product_quantity(token, product_id) <br>
delete_product(token, product_id) <br>
reset_buffer(token, product_id, updated_quantity) <br>
update_buffer(token, product_id, buffer) <br>
update_dimensions(token, product_id, height, length, width, weight, location) <br>
update_quantity(token, sku, product_id, quantity, dc_id) <br>
get_product_id_by_supplier_sku(token, mpn) <br>
get_product_id_by_mpn(token, mpn) <br>
get_sku_by_upc(token, upc) <br>